==> haskell-sandi-0.4.3-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.4.3
id: sandi-0.4.3-FCMAP4gZ9Fg3G8WMpEK9al
key: sandi-0.4.3-FCMAP4gZ9Fg3G8WMpEK9al
license: BSD-3-Clause
maintainer: Magnus Therning <magnus@therning.org>
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec, Conduit
abi: 5b94fb6169957b36009ee0f621e21ef9
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Paths_sandi Data.Conduit.Codec.Util
import-dirs: /usr/lib/ghc-8.6.3/site-local/sandi-0.4.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/sandi-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/sandi-0.4.3
hs-libraries: HSsandi-0.4.3-FCMAP4gZ9Fg3G8WMpEK9al
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1-BmabwSZESuG6iKDxLo0IET
    exceptions-0.10.0-9c5BjQipUdiGeORB8copQH
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandi-0.4.3-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.4.3
id: sandi-0.4.3-2lZB3XVjKbXIahNUU1eoKw
key: sandi-0.4.3-2lZB3XVjKbXIahNUU1eoKw
license: BSD-3-Clause
maintainer: Magnus Therning <magnus@therning.org>
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec, Conduit
abi: 842f14b362c6fee91cdb7673616aea13
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Paths_sandi Data.Conduit.Codec.Util
import-dirs: /usr/lib/ghc-8.6.3/site-local/sandi-0.4.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/sandi-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/sandi-0.4.3
hs-libraries: HSsandi-0.4.3-2lZB3XVjKbXIahNUU1eoKw
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1-AZTxIDI3CJlDMLereOgNtn
    exceptions-0.10.0-9c5BjQipUdiGeORB8copQH
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
